@@ -84,6 +84,7 @@ class CursorUtil(object):
             else:
                 parms_dict["param_value_" + str(param_index)] = str(x)
 
+        #print("parms_dict: " + str(parms_dict))
         return parms_dict
 
     @staticmethod
@@ -144,6 +145,7 @@ class CursorUtil(object):
         elif CursorUtil.get_class_name(x) == "datetime.time":
             sql_type = "TIME"
         else:
+            #print("CursorUtil.get_class_name(x): " + CursorUtil.get_class_name(x))
             raise TypeError("Type is not supported for value: " + str(x))
 
         return sql_type
@@ -157,3 +159,7 @@ class CursorUtil(object):
         s = s.replace("<type '", "")  # Python2 syntax
         s = s[0:len(s) - 2]
         return s
+
+    @staticmethod
+    def is_update_call(sql: str) -> bool:
+        return sql.lower().startswith("delete") or sql.lower().startswith("insert") or sql.lower().startswith("insert")
